/*****************************************************************************
*
*   INTERFAZ MODULO: lista_ap.h
*
*   LUGAR Y FECHA DE CREACION: Santiago de Cali, Diciembre de 2002.
*
*   Descripcion: TAD Lista: Implementado Sobre Apuntadores.
*
*   Requerimientos: Se requiere del Algoritmo de Control, un tipo de datos
*                   llamado elemento, para la parte info del nodo.
*
*****************************************************************************/

/*___________________________________________________________________________*

		 Declaracion de Constantes y Macros, publicas
*___________________________________________________________________________*/
#define FALSE 0            /* Estado de verdad = falso */
#define TRUE  1        /* Estado de verdad = verdadero */

/*___________________________________________________________________________*

	 Declaracion de Estructuras y Redefiniciones de Tipo, publicas
*___________________________________________________________________________*/
struct nodo
{
	elemento info;
	struct nodo *sgte;
};
typedef struct nodo *lista;

typedef int boolean;

/*___________________________________________________________________________*

		       Prototipos de Funciones Publicas
*___________________________________________________________________________*/
/* Inicializadora */
lista inic_lista(void);
/* pre: true
   post: lst=< > */

/* Constructoras */
lista ins_lista(lista lst, int pos, elemento elem);
/* pre: lst=<a1,a2,...,a(pos-1),a(pos),a(pos+1),...,an>; n>0; 1<=pos<=n; elem
   post: lst=<a1,a2,...,a(pos-1),elem,a(pos),a(pos+1),...,a(n+1)> */
lista anx_lista(lista lst, elemento elem);
/* pre: lst=<a1,a2,...,an>; elem
   post: lst=<a1,a2,...,an,elem>  */

/* Destructora */
lista elim_lista(lista lst, int pos);
/* pre: lst=<a1,a2,...,a(pos),...,an>; n>0; 1<=pos<=n
   post: lst=<a1,a2,...,a(n-1)>  */

/* Analizadoras */
elemento info_lista(lista lst, int pos);
/* pre: lst=<a1,a2,...,a(pos),...,an>; n>0; 1<=pos<=n
   post: a(pos)   */
int long_lista(lista lst);
/* pre: lst=<a1,a2,...,an>
   post: n        */

/*___________________________________________________________________________*

		       Prototipos de Funciones Privadas
*___________________________________________________________________________*/
/* Constructoras */
lista inv_lista(lista lst);
/* pre: lst=<a1,a2,...,an>
   post: lst=<an,a(n-1),...,a1>  */
lista concatenar_lista(lista lst1, lista lst2);
/* pre: lst1=<a1,a2,...,an>; lst2=<b1,b2,...,bn>
   post: lst= <a1,a2,...,an,b1,b2,...,bn>  */
lista cambiar_lista(lista lst, int pos, elemento elem);
/* pre: lst=<a1,a2,...,a(pos-1),a(pos),a(pos+1),...,an>; n>0; 1<=pos<=n; elem
   post: lst=<a1,a2,...,a(pos-1),elem,a(pos+1),...,a(n+1)> */
lista intercambiar_lista(lista lst, int pospri, int posfin);
/* pre: lst=<a1,a2,...,a(pospri),...,a(posfin),...,an>; n>0
   post: lst=<a1,a2,...,a(posfin),...,a(pospri),...,an)> */

/* Destructora */
lista dest_lista(lista lst);
/* pre: lst=<a1,a2,...,an>
   post: lst=< >  */

/* Analizadoras */
elemento pre_lista(lista lst, int pos);
/* pre: lst=<a1,a2,...,a(pos-1),a(pos),...,an>; n>0; 1<=pos<=n
   post: a(pos-1)   */
elemento suc_lista(lista lst, int pos);
/* pre: lst=<a1,a2,...,a(pos),a(pos+1),...,an>; n>0; 1<=pos<=n
   post: a(pos+1)   */
elemento prim_lista(lista lst);
/* pre: lst=<a1,a2,...,an>
   post: a1   */
elemento ult_lista(lista lst);
/* pre: lst=<a1,a2,...,an>
   post: an   */
boolean vacia_lista(lista lst);
/* pre: lst TRUE
   post: si (lst==< >) => retorna (TRUE), sino => retorna (FALSE)   */

#include "c:\analogs\lista_ap.c"